#
# spec file for package zstd
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major 1
%define libname lib%{name}%{major}
Name:           zstd
Version:        %{major}.3.8
Release:        23.4
Summary:        Zstandard compression tools
License:        BSD-3-Clause AND GPL-2.0-only
Group:          Productivity/Archiving/Compression
URL:            https://github.com/facebook/zstd
Source0:        https://github.com/facebook/zstd/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch1:         pzstd.1.patch
Patch2:         pzstd-global-gtest.patch
BuildRequires:  gcc
# C++ is needed for pzstd only
BuildRequires:  gcc-c++
BuildRequires:  googletest-devel
BuildRequires:  pkgconfig

%description
Zstd, short for Zstandard, is a lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

Zstd can also offer stronger compression ratios at the cost of
compression speed. Speed vs. compression trade-off is configurable by
small increments. Decompression speed is preserved and remains
roughly the same at all settings, a property shared by most LZ
compression algorithms, such as zlib or lzma.

%package -n %{libname}
Summary:        Zstd compression library
Group:          System/Libraries

%description -n %{libname}
Zstd, short for Zstandard, is a lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

This subpackage contains the implementation as a shared library.

%package -n lib%{name}-devel
Summary:        Development files for the Zstd compression library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glibc-devel

%description -n lib%{name}-devel
Zstd, short for Zstandard, is a lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

Needed for compiling programs that link with the library.

%package -n lib%{name}-devel-static
Summary:        Development files for the Zstd compression library
Group:          Development/Libraries/C and C++
BuildRequires:  glibc-devel-static
Requires:       lib%{name}-devel = %{version}

%description -n lib%{name}-devel-static
Zstd, short for Zstandard, is a lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

Needed for compiling programs that link with the library.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags} -std=c++11"
for dir in lib programs contrib/pzstd; do
  make %{?_smp_mflags} -C "$dir"
done

%check
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags} -std=c++11"
make %{?_smp_mflags} -C tests test-zstd
#make %{?_smp_mflags} -C contrib/pzstd test-pzstd

%install
%make_install PREFIX=%{_prefix} LIBDIR=%{_libdir}
install -D -m755 contrib/pzstd/pzstd %{buildroot}%{_bindir}/pzstd
install -D -m644 programs/zstd.1 %{buildroot}%{_mandir}/man1/pzstd.1

%files
%license COPYING LICENSE
%doc README.md CHANGELOG
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%files -n %{libname}
%license COPYING LICENSE
%{_libdir}/libzstd.so.*

%files -n lib%{name}-devel
%license COPYING LICENSE
%{_includedir}/*.h
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/libzstd.so

%files -n lib%{name}-devel-static
%license COPYING LICENSE
%{_libdir}/libzstd.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%changelog
* Sat Jan  5 2019 astieger@suse.com
- zstd 1.3.8:
  * better decompression speed on large files (+7%%) and cold
    dictionaries (+15%%)
  * slightly better compression ratio at high compression modes
  * new --rsyncable mode
  * support decompression of empty frames into NULL (used to be an
    error)
  * support ZSTD_CLEVEL environment variable
  * --no-progress flag, preserving final summary
  * various CLI fixes
* Wed Oct 24 2018 astieger@suse.com
- zstd 1.3.7:
  * fix ratio for dictionary compression at levels 9 and 10
  * add man pages for zstdless and zstdgrep
- includes changes from zstd 1.3.6:
  * faster dictionary builder, also the new default for --train
  * previous (slower, slightly higher quality) dictionary builder
    to be selected via --train-cover
  * Faster dictionary decompression and compression under memory
    limits with many dictionaries used simultaneously
  * New command --adapt for compressed network piping of data
    adjusted to the perceived network conditions
- drop zstd-1.3.5-fix-list-stdin.patch, upstream
- switch from git tag snaphshot to bootstrapped tarball
* Tue Jul  3 2018 astieger@suse.com
- update to 1.3.5:
  * much faster dictionary compression
  * small quality improvement for dictionary generation
  * slightly improved performance at high compression levels
  * automatic memory release for long duration contexts
  * fix overlapLog can be manually set
  * fix decoding invalid lz4 frames
  * fix performance degradation for dictionary compression when
    using advanced API
- add zstd-1.3.5-fix-list-stdin.patch to avoid test issues with
  - -list when stdin is not a tty, patch from upstream
- disable failing pzstd tests
* Thu Jun 14 2018 sweet_f_a@gmx.de
- fix pzstd tests
- add pzstd-global-gtest.patch
* Thu Jun 14 2018 sweet_f_a@gmx.de
- enable pzstd (parallel zstd)
- add pzstd.1.patch, taken from Fedora package (git 21908004)
* Thu May 24 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Wed Mar 28 2018 idonmez@suse.com
- Update to 1.3.4
  * perf: faster speed (especially decoding speed) on recent cpus
    (haswell+)
  * perf: much better performance associating --long with
    multi-threading
  * perf: better compression at levels 13-15
  * cli : asynchronous compression by default, for faster
    experience (use --single-thread for former behavior)
  * cli : smoother status report in multi-threading mode
  * cli : added command --fast=#, for faster compression modes
  * cli : fix crash when not overwriting existing files
  * api : `nbThreads` becomes `nbWorkers` : 1 triggers
    asynchronous mode
  * api : compression levels can be negative, for even more speed
  * api : ZSTD_getFrameProgression() : get precise progress
    status of ZSTDMT anytime
  * api : ZSTDMT can accept new compression parameters during
    compression
  * api : implemented all advanced dictionary decompression prototypes
* Mon Feb  5 2018 dsterba@suse.cz
- build the static library (depency for btrfsprogs-static)
* Thu Dec 21 2017 idonmez@suse.com
- Update to 1.3.3
  * perf: improved zstd_opt strategy (levels 16-19)
  * fix : bug #944 : multithreading with shared ditionary and
    large data, reported by @gsliepen
  * cli : fix : content size written in header by default
  * cli : fix : improved LZ4 format support, by @felixhandte
  * cli : new : hidden command -b -S, to benchmark multiple files
    and generate one result per file
  * api : change : when setting pledgedSrcSize, use
    ZSTD_CONTENTSIZE_UNKNOWN macro value to mean "unknown"
  * api : fix : support large skippable frames, by @terrelln
  * api : fix : re-using context could result in suboptimal
    block size in some corner case scenarios
  * api : fix : streaming interface was adding a useless
    3-bytes null block to small frames
* Sun Oct 29 2017 astieger@suse.com
- update to 1.3.2:
  * new long range mode, using --long command
  * new ability to generate and decode magicless frames
  * changed maximum nb of threads reduced to 200, to avoid address
    space exhaustion in 32-bits mode
  * fix multi-threading compression works with custom allocators
  * fix ZSTD_sizeof_CStream() was over-evaluating memory usage
  * fix a rare compression bug when compression generates very large
    distances and bunch of other conditions
    (only possible at --ultra -22)
  * fix 32-bits build can now decode large offsets (levels 21+)
  * cli added LZ4 frame support by default
  * cli improved --list output
  * cli now can split input file for dictionary training, using
    command -B#
  * cli new clean operation artefact on Ctrl-C interruption
  * do not change /dev/null permissions when using command -t with
    root access
  * cli fix write file size in header in multiple-files mode
  * api: added macro ZSTD_COMPRESSBOUND() for static allocation
  * api: new advanced decompression API
  * api: sizeof_CCtx() used to over-estimate
  * build: fix : no-multithread variant compiles without pool.c
    dependency
  * build: better compatibility with reproducible builds
  * license: changed /examples license to BSD + GPLv2
  * license: fix a few header files to reflect new license
* Mon Aug 21 2017 idonmez@suse.com
- Update to v1.3.1
  * License is now BSD + GPL-2.0
  * See https://github.com/facebook/zstd/releases for the
    complete changelog.
* Mon Mar 27 2017 idonmez@suse.com
- Update to v1.1.4
  See https://github.com/facebook/zstd/releases for details.
- Drop zstd-lib-no-rebuild.patch
* Wed Dec  7 2016 idonmez@suse.com
- Fix group name for the shared library
* Sun Dec  4 2016 idonmez@suse.com
- Update to version 1.1.1
  * New : cli commands -M#, --memory=, --memlimit=,
  - -memlimit-decompress= to limit allowed memory consumption
    during decompression
  * Improved : slightly better compression ratio at --ultra levels
  * Improved : better memory usage when using streaming
    compression API
  * Added : API : ZSTD_initCStream_usingCDict(),
    ZSTD_initDStream_usingDDict() (experimental section)
  * Changed : zstd_errors.h is now installed within /include
    (and replaces errors_public.h)
  * Fixed : several sanitizer warnings
* Sun Oct 16 2016 jengelh@inai.de
- Update descriptions
* Wed Oct  5 2016 bwiedemann@suse.com
- initial package version 1.1.0
  based on https://pbrady.fedorapeople.org/zstd.spec
